photos

package
v1.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2026 License: MIT Imports: 26 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Photo

type Photo struct {
	Thumbnail string
	Page      string
	Original  string
	Exif      *exif.Exif
	Time      time.Time
}

func NewPhoto

func NewPhoto(photoPath string) (*Photo, error)

NewPhoto creates a Photo instance from a filesystem path. The path must be within allowed directories. Returns an error if the path is invalid or the file cannot be read.

func (*Photo) AST added in v1.7.0

func (*Photo) AST() ([]byte, ast.Node)

func (*Photo) Content added in v1.7.0

func (*Photo) Content() xlog.Markdown

func (*Photo) Delete added in v1.7.0

func (*Photo) Delete() bool

func (*Photo) Exists added in v1.7.0

func (*Photo) Exists() bool

func (*Photo) FileName added in v1.7.0

func (*Photo) FileName() string

func (*Photo) ModTime added in v1.7.0

func (*Photo) ModTime() time.Time

func (*Photo) Name

func (p *Photo) Name() string

func (*Photo) Render added in v1.7.0

func (p *Photo) Render() template.HTML

func (*Photo) Write added in v1.7.0

func (*Photo) Write(xlog.Markdown) bool

type Photos added in v1.7.0

type Photos struct{}

func (Photos) Init added in v1.7.0

func (Photos) Init()

func (Photos) Name added in v1.7.0

func (Photos) Name() string

type Property added in v1.7.0

type Property struct {
	IconVal string
	NameVal string
	Val     any
}

func (Property) Icon added in v1.7.0

func (p Property) Icon() string

func (Property) Name added in v1.7.0

func (p Property) Name() string

func (Property) Value added in v1.7.0

func (p Property) Value() any

Jump to